@@ -11,6 +11,13 @@ explore <- function (ka, coltxt="black",
         stop("ka should be defined in two dimensions")
     if ((gr[1, 2] - gr[2, 2])> get(".adeoptions", envir=.adehabitatMAEnv)$epsilon)
         stop("the cellsize should be the same in x and y directions")
+    if (!all(sapply(1:ncol(ka), function(i) is.numeric(ka[[i]])))) {
+        warning("Not all variables in ka are numeric.\nOther variables have been converted to numeric")
+        for (j in 1:ncol(ka)) {
+            if (!is.numeric(ka[[j]]))
+                ka[[j]] <- as.numeric(factor(ka[[j]]))
+        }
+    }
 
     e1 <- new.env(parent = baseenv())
     assign("nn", NULL, envir=e1)
@@ -72,9 +79,6 @@ explore <- function (ka, coltxt="black",
     opt <- options(warn = -1)
     on.exit(options(opt))
 
-    if (!require(tkrplot))
-        stop("'tkrplot' package needed\n")
-
     help.txt <- paste("\n-------- to obtain this help, type 'h' ------------------",
                       "z/o            -- Zoom in/Out",
                       "Right-Click    -- Identify value",
@@ -84,23 +88,23 @@ explore <- function (ka, coltxt="black",
                       "---------------------------------------------------------",
                       "\n", sep = "\n")
 
-    tt <- tktoplevel()
-    tkwm.title(tt, "Exploration of SpatialPixelsDataFrame")
-    img <- tkrplot(tt, replot, hscale = hscale, vscale = vscale)
-    txt <- tktext(tt, bg = "white", font = "courier 10")
-    scr <- tkscrollbar(tt, repeatinterval = 5, command = function(...) tkyview(txt, ...))
-    tkconfigure(txt, yscrollcommand = function(...) tkset(scr,
-                     ...))
-    tkpack(img, side = "top")
-    tkpack(txt, side = "left", fill = "both", expand = TRUE)
-    tkpack(scr, side = "right", fill = "y")
-    iw <- as.numeric(tcl("image", "width", tkcget(img, "-image")))
-    ih <- as.numeric(tcl("image", "height", tkcget(img, "-image")))
+    tt <- tcltk::tktoplevel()
+    tcltk::tkwm.title(tt, "Exploration of SpatialPixelsDataFrame")
+    img <- tkrplot::tkrplot(tt, replot, hscale = hscale, vscale = vscale)
+    txt <- tcltk::tktext(tt, bg = "white", font = "courier 10")
+    scr <- tcltk::tkscrollbar(tt, repeatinterval = 5, command = function(...) tcltk::tkyview(txt, ...))
+    tcltk::tkconfigure(txt, yscrollcommand = function(...) tcltk::tkset(scr,
+                            ...))
+    tcltk::tkpack(img, side = "top")
+    tcltk::tkpack(txt, side = "left", fill = "both", expand = TRUE)
+    tcltk::tkpack(scr, side = "right", fill = "y")
+    iw <- as.numeric(tcltk::tcl("image", "width", tcltk::tkcget(img, "-image")))
+    ih <- as.numeric(tcltk::tcl("image", "height", tcltk::tkcget(img, "-image")))
 
-    showz <- function() tkrreplot(img)
+    showz <- function() tkrplot::tkrreplot(img)
     type <- function(s) {
-        tkinsert(txt, "end", s)
-        tksee(txt, "end")
+        tcltk::tkinsert(txt, "end", s)
+        tcltk::tksee(txt, "end")
     }
     type(help.txt)
     cc <- function(x, y) {
@@ -186,7 +190,7 @@ explore <- function (ka, coltxt="black",
     kb <- function(A) {
         key <- tolower(A)
         if (key == "q") {
-            tkdestroy(tt)
+            tcltk::tkdestroy(tt)
             return("OK - Finished")
         }
         if (key == "z") {
@@ -203,10 +207,10 @@ explore <- function (ka, coltxt="black",
         }
     }
     showz()
-    tkbind(tt, "<Key>", kb)
-    tkbind(img, "<Button-1>", mm.t)
-    tkbind(img, "<Motion>", mm.mouset)
-    tkbind(img, "<Button-3>", mm.t2)
-    tkwait.window(tt)
+    tcltk::tkbind(tt, "<Key>", kb)
+    tcltk::tkbind(img, "<Button-1>", mm.t)
+    tcltk::tkbind(img, "<Motion>", mm.mouset)
+    tcltk::tkbind(img, "<Button-3>", mm.t2)
+    tcltk::tkwait.window(tt)
 
 }
